@@ -9,7 +9,7 @@
 #' @param cache_connection Defaults to NULL. If NULL, and caching is enabled, `tidywikidatar` will use a local sqlite database. A custom connection to other databases can be given (see vignette `caching` for details).
 #' @param disconnect_db Defaults to TRUE. If FALSE, leaves the connection to cache open.
 #' @param wait In seconds, defaults to 1 due to time-outs with frequent queries. Time to wait between queries to the APIs. If data are cached locally, wait time is not applied. If you are running many queries systematically you may want to add some waiting time between queries.
-#' @param attempts Defaults to 5. Number of times it re-attempts to reach the API before failing.
+#' @param attempts Defaults to 10. Number of times it re-attempts to reach the API before failing.
 #'
 #' @return A data frame (a tibble) with eight columns: `source_title_url`, `source_wikipedia_title`, `source_qid`, `wikipedia_title`, `wikipedia_id`, `qid`, `description`, and `language`.
 #' @export
@@ -37,7 +37,7 @@ tw_get_wikipedia_category_members <- function(url = NULL,
                                               cache_connection = NULL,
                                               disconnect_db = TRUE,
                                               wait = 1,
-                                              attempts = 5) {
+                                              attempts = 10) {
   db <- tw_connect_to_cache(
     connection = cache_connection,
     language = language,
@@ -63,7 +63,7 @@ tw_get_wikipedia_category_members <- function(url = NULL,
       source_qid = .data$qid,
       language = .data$language
     ) %>%
-    dplyr::distinct(.data$source_qid, .keep_all = TRUE)
+    dplyr::distinct(.data$source_title_url, .keep_all = TRUE)
 
   wikipedia_category_members_df <- purrr::map_dfr(
     .x = seq_along(source_df$source_wikipedia_category),
@@ -126,7 +126,7 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
                                                      cache_connection = NULL,
                                                      disconnect_db = TRUE,
                                                      wait = 1,
-                                                     attempts = 5) {
+                                                     attempts = 10) {
   db <- tw_connect_to_cache(
     connection = cache_connection,
     language = language,
@@ -157,6 +157,8 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
     } else {
       category_df <- tidywikidatar::tw_empty_wikipedia_category_members
     }
+  } else {
+    category_df <- tidywikidatar::tw_empty_wikipedia_category_members
   }
 
   if (nrow(category_df) == 0) {
